Ubuntu 16.04 Update Mouse Cursor Hidden

Having this issue with 14.1.2 and Ubuntu 16.04. It just started today, not sure if Ubuntu or Parallels updated. Have tried a few reboots and video.hw_pointer=0 boot flag. Reinstalling Parallels tools also fails. Host's home is missing for me too.
 
Same issue here on Ubuntu 16.04 with Parallels 14.1.3.
I have nevertheless a (awful) workaround that allows *minimal* interaction with the system (and a hidden mouse cursor): Press Ctrl+Option to release mouse from Parallels into MacOS, then move the mouse to the desired location. You can then clock and have the (invisible) mouse directly over the desired location. Use next click to execute mouse click in the virtual machine. Not a sustainable solution, but better than nothing....
 
The problem seems to be that the kernel module provided by the Parallel Tools is not compatible with newer versions of the Linux kernel yet. Therefore, the DKMS triggered build fails with an error (the arguments to the get_user_pages function seem to have changed).

Until Parallels releases an updated version of the Parallels Tools that is compatible with the new kernel, the only way to fix this problem is staying on the old kernel version (4.4.0-142 still works). The other packages can be updated without any problems.
 
Last edited:
Still having this issue August 2019 running Ubuntu 18.04 on MacOS Mojave 10.14.5. Had had similar issues running 18.04 on VirtualBox. Attempted solution through Gnome proposed on Ask Ubuntu but it was ineffective. Was hoping Parallels would have been on top of this. I'm currently running the free trial and won't invest in the software if I can't get something as basic as the cursor to work.
 
Same here. It works on the initial install of Ubuntu 18.04 and then as soon as you run an update BOOM missing cursor and Parallels Tools fails to install. I am so pissed of with Parallels right now for abandoning us.
 
I was given these instructions by customer support: https://kb.parallels.com/113394
It's a command-line method that was not able to successfully install after multiple attempts. For Step 2, I had no "Default" option for either of my 2 virtual CD/DVD drives, only "Disconnect". Still no success after disconnecting drive 1.
Screen Shot 2019-08-04 at 2.36.28 PM.png Screen Shot 2019-08-04 at 2.36.32 PM.png
 
I heard back from customer support, and their brief response is:
"Ubuntu Linux kernel version 5.0.0-23-generic is not supported in Parallels Desktop for Mac."

Which I guess is our answer.
 
Here is the best way I found to manage this issue:
1- As mentioned above the issue is because of the latest Kernel.
2- Restart Ubuntu and run Grub as follows, restart then click in the window to select it and press shift to boot in the grub menu.
3- select advanced and then choose to boot using an older kernel.
 
Here is the best way I found to manage this issue:
1- As mentioned above the issue is because of the latest Kernel.
2- Restart Ubuntu and run Grub as follows, restart then click in the window to select it and press shift to boot in the grub menu.
3- select advanced and then choose to boot using an older kernel.
What do you mean by "run Grub as follows"? I haven't been able to boot Grub by pressing Shift or Esc at startup - it goes directly to Ubuntu.
 
It looks like this might work:
https://forums.parallels.com/threads/kernel-5-0-3.346841/
From @(GalaxyMaster):
The only module that is failing with the latest Parallels Tools (14.1.3) is prl_fs and the fix is trivial:
Code:
diff -puNr parallels.orig/prl_fs/SharedFolders/Guest/Linux/prl_fs/super.c parallels/prl_fs/SharedFolders/Guest/Linux/prl_fs/super.c
--- parallels.orig/prl_fs/SharedFolders/Guest/Linux/prl_fs/super.c    2018-09-07 13:15:08.000000000 +0000
+++ parallels/prl_fs/SharedFolders/Guest/Linux/prl_fs/super.c    2019-04-02 06:45:15.675125322 +0000
@@ -116,11 +116,11 @@ static int prlfs_remount(struct super_bl
 {
     int ret = 0;
     DPRINTK("ENTER\n");
-    if ( (!((*flags) & MS_RDONLY) && PRLFS_SB(sb)->readonly) ||
-           ((*flags) & MS_MANDLOCK) )
+    if ( (!((*flags) & SB_RDONLY) && PRLFS_SB(sb)->readonly) ||
+           ((*flags) & SB_MANDLOCK) )
             ret = -EINVAL;
 
     *flags |= MS_SYNCHRONOUS; /* silently don't drop sync flag */
     DPRINTK("EXIT returning %d\n", ret);
     return ret;
 }
@@ -270,7 +270,7 @@ static int prlfs_fill_super(struct super
     sb->s_maxbytes = MAX_LFS_FILESIZE;
     sb->s_blocksize = PAGE_SIZE;
     sb->s_blocksize_bits = PAGE_SHIFT;
-    sb->s_flags |= MS_NOATIME | MS_SYNCHRONOUS;
+    sb->s_flags |= SB_NOATIME | SB_SYNCHRONOUS;
     sb->s_magic = PRLFS_MAGIC;
     sb->s_op = &prlfs_super_ops;
     PRLFS_ALLOC_SB_INFO(sb);
@@ -116,11 +116,11 @@ static int prlfs_remount(struct super_bl
             ret = -EINVAL;
 
-    *flags |= MS_SYNCHRONOUS; /* silently don't drop sync flag */
+    *flags |= SB_SYNCHRONOUS; /* silently don't drop sync flag */
     DPRINTK("EXIT returning %d\n", ret);
     return ret;

Steps:
1. while still under kernel 4.20.16 (or other 4.x.x), mount the virtual Tools CD ISO in Parallels (prl_tools_lin.iso) and copied it into a directory called tools_cd
2. make everything under tools_cd writable (chmod -R +w .)
3. cd into kmods and untar the tools file (tar -zcvpf prl_mod.tar.gz)
4. cd to prl_fs/SharedFolders/Guest/Linux/prl_fs (cd prl_fs/SharedFolders/Guest/Linux/prl_fs)
5. edit super.c by copying/pasting the offending 'MS_' lines shown in the diff and prefacing each with macros to allow rebuilding under the current kernel (note that there are three such sections in the diff above, this is just the first):
#if LINUX_VERSION_CODE < KERNEL_VERSION(5,0,0)
if ( (!((*flags) & MS_RDONLY) && PRLFS_SB(sb)->readonly) ||
((*flags) & MS_MANDLOCK) )
#else
if ( (!((*flags) & SB_RDONLY) && PRLFS_SB(sb)->readonly) ||
((*flags) & SB_MANDLOCK) )
#endif
6. cd back up to the kmods directory and delete the current prl_mod.tar.gz (rm -rf prl_mod.tar.gz)
7. re-tar/gz the edits into a new one (tar -zcvpf prl_mod.tar.gz .)
8. cd up a level (cd ..) and re-run the installer *as an upgrade* (./install). You can also do the Remove, reboot, remember to enter the directory and run the install, but that's a few extra time-consuming steps.
9. when done, reboot the VM back into the same kernel as before, then upgrade the kernel using dnf (or other). In my case I had to remember to comment out the exclude line in /etc/dnf/dnf.conf first. As the new kernel is installed, it should automatically rebuild Tools in the background.
10. Reboot the VM again into the new kernel, everything should work. Can now reset Grub2 to use the first kernel listed (grub2-set-default 0), unmount the Tools image, and delete the tools_cd directory as cleanup, if needed.

Currently running on 5.0.7... Cheers @GalaxyMaster for tracking down the fix.
 
Back
Top